@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef INCIDENCEEDITOR_EDITORCONFIG_H
-#define INCIDENCEEDITOR_EDITORCONFIG_H
+#pragma once
 
 #include "incidenceeditor_export.h"
 
@@ -107,4 +106,3 @@ private:
 };
 }
 
-#endif
