@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef INCIDENCEEDITOR_EDITORITEMMANAGER_H
-#define INCIDENCEEDITOR_EDITORITEMMANAGER_H
+#pragma once
 
 #include <Akonadi/Calendar/IncidenceChanger>
 #include <Collection>
@@ -14,7 +13,6 @@
 
 namespace Akonadi
 {
-class Collection;
 class Item;
 }
 
@@ -170,4 +168,3 @@ public:
 };
 }
 
-#endif
